/* FixLocDates.cmd */

/* 
This script will change current Local End dates in ebay.dat to match
the users Locale setting. It will also change dates in the Item Status
(highbids.dat) file to be consistent with other formats for Local dates
in the program.

It must be run BEFORE running ver 1.09i to ensure no new items are added
with the newer date format. 

It should only be run ONCE. If it is rerun against the same data files,
the dates will be changed, and not match the format of any new items.

The script will backup the current file to a .bk2 file.

*/
   

DateFmt = substr(SysIni('USER','PM_National','iDate'),1,1)

if DateFmt = 1 then do

/* Fix Local End date for local format */
  infile = 'ebay.bk2'
  outfile = 'ebay.dat'

  if stream( outfile, 'c', 'query exists' ) = '' then do
    say 'Data file "ebay.dat" not found, cannot continue'
    '@exit'
  end

  recs = 0

  if stream( infile, 'c', 'query exists' ) > '' then
    '@del 'infile 
  '@ren 'outfile infile
  call FixLocDates

  say 'Checking Archive '
  outfile = 'ebayarc.dat'
  if stream( outfile, 'c', 'query exists' ) > '' then do
    recs = 0
    infile = 'ebayarc.bk2'
    if stream( infile, 'c', 'query exists' ) > '' then
      '@del 'infile
    '@ren 'outfile infile
    call FixLocDates
  end
  else
    say 'No archive file found'
end
else
  say 'Local dates match Locale, format not changed'

infile = 'highbids.bk2'
outfile = 'highbids.dat'
say
if stream( outfile, 'c', 'query exists' ) = '' then do
  say 'Data file "highbids.dat" not found, fixup skipped'
  '@exit'
end

say
say ' If you have NOT been using the default format (yy/mm/dd) for dates entered'
say ' in your Item Status (highbids.dat) records, press "Q" at the next prompt'
say 
say 'Press Enter to continue, or "Q" to abort:'

parse pull Ans

if translate(Ans) = 'Q' then
 exit

/* Fix Item Status Local End date for dd/mm/yy format */

recs = 0

if stream( infile, 'c', 'query exists' ) > '' then
  '@del 'infile 
'@ren 'outfile infile
call FixStDates

'@exit'


FixLocDates:

rc = stream( infile, 'c', 'open' )
rc = stream( outfile, 'c', 'open' )

do while lines( infile )
  iline = linein( infile )
  LocEnds = substr(iline,226,8)
  iline = overlay(substr(LocEnds,4,3)||substr(LocEnds,1,2),iline,226)
  rc = lineout( outfile, iLine )
  recs = recs + 1
end

rc = stream( infile, 'c', 'close' )
rc = stream( outfile, 'c', 'close' )
say outfile': Fixed 'recs 'date record(s)'
return


FixStDates:

rc = stream( infile, 'c', 'open' )
rc = stream( outfile, 'c', 'open' )

do while lines( infile )
  iline = linein( infile )
  parse value iline with junk 11 ConDate 19 ConNote 99 PayDate 107 PayNote 187 RecDate 195 RecNote 275 FBDate 283 FBNote
  if DateFmt = 1 then do
    iline = overlay(substr(ConDate,7,2)||substr(ConDate,3,4)||substr(ConDate,1,2),iline,11)
    iline = overlay(substr(PayDate,7,2)||substr(PayDate,3,4)||substr(PayDate,1,2),iline,99)
    iline = overlay(substr(RecDate,7,2)||substr(RecDate,3,4)||substr(RecDate,1,2),iline,187)
    iline = overlay(substr(FBDate,7,2)||substr(FBDate,3,4)||substr(FBDate,1,2),iline,275)
  end
  else do
    iline = overlay(substr(ConDate,4,2)||substr(ConDate,7,2)||substr(ConDate,1,2),iline,11)
    iline = overlay(substr(PayDate,4,2)||substr(PayDate,7,2)||substr(PayDate,1,2),iline,99)
    iline = overlay(substr(RecDate,4,2)||substr(RecDate,7,2)||substr(RecDate,1,2),iline,187)
    iline = overlay(substr(FBDate,4,2)||substr(FBDate,7,2)||substr(FBDate,1,2),iline,275)
  end
  rc = lineout( outfile, iLine )
  recs = recs + 1
end

rc = stream( infile, 'c', 'close' )
rc = stream( outfile, 'c', 'close' )
say outfile': Fixed 'recs 'date record(s)'
return

